A minimal ggplot2 theme for maps: no axes or grid, legend at the right, small grey caption.
See also
Other mapping helpers:
mn_aimag_grid,
mn_crs(),
mn_label_points(),
mn_leaflet(),
mn_map()
A minimal ggplot2 theme for maps: no axes or grid, legend at the right, small grey caption.
Other mapping helpers:
mn_aimag_grid,
mn_crs(),
mn_label_points(),
mn_leaflet(),
mn_map()