| mn_label_points | R Documentation |
Returns one point per unit, placed well inside its polygon (unlike a
centroid, which can fall outside curved shapes). Points for the maps in
this package are precomputed; other polygons use
sf::st_point_on_surface().
mn_label_points(x)
x |
An |
An sf object of points with the attributes of x.
Other mapping helpers:
mn_aimag_grid,
mn_crs(),
mn_leaflet(),
mn_map(),
theme_mn()
mn_label_points(mn_aimags())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.