View source: R/layers-raster.R
| mn_zonal | R Documentation |
Adds a column to x with a summary of the raster cells in each unit, for
example the total population of every soum or the mean elevation of every
aimag.
mn_zonal(
r,
x = NULL,
fun = c("sum", "mean", "min", "max", "median"),
name = "value"
)
r |
A |
x |
An |
fun |
Summary function name: |
name |
Name of the new column. |
x with a new column.
Other raster layers:
mn_elevation(),
mn_landcover(),
mn_population()
soum_pop <- mn_zonal(mn_population(2025), mn_soums(), name = "population")
mn_map(soum_pop, fill = population / area_km2, trans = "log10")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.